<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LineParallelThrough</name>
    <message>
        <location filename="../LineParallelThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <location filename="../LineParallelThroughInit.js" line="+2"/>
        <source>Par&amp;allel (through Point)</source>
        <translation>平行（过点）(&amp;a)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel line or concentric arc or circle through a given point</source>
        <translation>绘制通过给定点的平行线或同轴弧、圆</translation>
    </message>
</context>
</TS>
